% Quokka3 settingsfile for Longi 26.8% HJT cell
% cell properties extracted from Lin et. al, Silicon heterojunction solar cells with up to 26.81% efficiency achieved by electrically optimized nanocrystalline-silicon hole contact layers, nature energy Vol 8, 2023

% (c) 2024 Andreas Fell
 
Syntax = 'front and rear contact unit cell';
 
UnitCellType = 'standard';
 
% Wafer settings
CellThickness = 130 um;
FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';
 
Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus fixed-lifetime';
Bulk.Electrical.Recombination.FixedLifetime = 40ms; % background SRH lifetime
Thermal.T = 25 degC;
 
 
% ExternalCircuit settings
ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.1282; % front finger resistance from Fig. 2d 0.0882 plus vertical skin resistivties 0.035 + 0.005
ExternalCircuit.Rshunt = 1e6;
ExternalCircuit.DiodeJ0 = 0;
ExternalCircuit.DiodeIdeality = 2;
  
 
% Front grid design
FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 1.64 mm;
FrontFingerWidth = 40 um;
FrontContactWidth = 40 um;
FrontFingerShadingFraction = 0.6;
FrontContact.OhmicResistivity = 1 mOhmcm2; % guess
 
% Back grid design
RearContactShape = 'line';
RearMetalShape = 'H-pattern';
RearContactPitch = 0.82 mm;
RearFingerWidth = 90 um;
RearContactWidth = 90 um;
RearFingerShadingFraction = 0.8;
RearContact.OhmicResistivity = 1 mOhmcm2; % guess
 
% Solver settings
Solver.SolutionType = 'light JV-curve';
Solver.Electrical.VocGuess = 0.75;
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 25 degC;
Solver.PhotonRecycling.Enable = 1; % photon recycling results in few mV higher Voc, relevant to match very high measured Voc; DISABLED TO RUN IN FREE VERSION
 
% Optical settings
Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.TextZ.FrontText.Type = 'Text'; % Text and Aext extracted from Fig 5b
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'Text.csv';
Optical.TextZ.FrontText.Aext.Type = 'file';
Optical.TextZ.FrontText.Aext.File = 'Aext.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local';
 
Optical.ScaleGeneration = 1;
 
% Full area FRONT skin properties
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 113;
FullFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 0 fA/cm2;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 0 fA/cm2; % only zero surface recombination matches measured Voc, difference to ~1 fA/cm2 given in paper might be explainable by different Auger models used in simulations and J0 measurements, or by Niewelt Auger still underestimating true Auger lifetime
% FullFrontSkin.Lumped.Electrical.VerticalResistivityEnable = 1; DISABLED TO RUN IN FREE VERSION, added to external series resistance
% FullFrontSkin.Lumped.Electrical.VerticalResistivity.OhmicResistivity = 0.035; % extracted from Fig 2d
FullFrontSkin.OpticalModelType = 'lumped';
FullFrontSkin.Lumped.Optical.Internal.Rint = 0.898; % from fitting Resc and EQE from Fig 5b
FullFrontSkin.Lumped.Optical.Internal.RintFirstEnable = 1;
FullFrontSkin.Lumped.Optical.Internal.RintFirst = 0.8143; % from fitting Resc and EQE from Fig 5b
FullFrontSkin.Lumped.Optical.Internal.Diffuse = 1;
FullFrontSkin.Lumped.Optical.Internal.Appp = 0.00377; % from fitting Resc and EQE from Fig 5b, represents mainly TCO absorption
 
% Full area BACK skin properties
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 116;
FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0 = 0 fA/cm2;
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.J0 = 0 fA/cm2; % only zero surface recombination matches measured Voc, difference to ~1 fA/cm2 given in paper might be explainable by different Auger models used in simulations and J0 measurements, or by Niewelt Auger still underestimating true Auger lifetime
% FullRearSkin.Lumped.Electrical.VerticalResistivityEnable = 1; DISABLED TO RUN IN FREE VERSION, added to external series resistance
% FullRearSkin.Lumped.Electrical.VerticalResistivity.OhmicResistivity = 0.005; % extracted from Fig 2d
FullRearSkin.OpticalModelType = 'lumped';
FullRearSkin.Lumped.Optical.Internal.Rint = 0.995; % assumes highly reflective chuck
FullRearSkin.Lumped.Optical.Internal.Diffuse = 1;
FullRearSkin.Lumped.Optical.Internal.Appp = 0.00377; % from fitting Resc and EQE from Fig 5b, represents mainly TCO absorption
